@@ -21,7 +21,7 @@ use XSLoader;
 our @EXPORT    = qw();
 our @EXPORT_OK = qw(load getloadavg proc_loadavg uptime);
 
-our $VERSION = '0.27'; # TRIAL
+our $VERSION = '0.28'; # TRIAL
 
 XSLoader::load 'Sys::CpuLoad', $VERSION;
 
@@ -56,7 +56,7 @@ sub uptime {
     return undef if $? || !defined($line);
     if ( $line =~ /(\d+[,.]\d+)\s*,?\s+(\d+[,.]\d+)\s*,?\s+(\d+[,.]\d+)\s*$/m )
     {
-        return ( map { $_ + 0 } ( $1, $2, $3 ) );
+        return ( map { my $n = $_; $n =~ tr/,/./; $n + 0 } ( $1, $2, $3 ) );
     }
     return undef;
 }
@@ -96,7 +96,7 @@ Sys::CpuLoad - retrieve system load averages
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
